==> glademm_0.1.9.orig.tar.gz: glademm-0.1.9/src/writers/scrollbar.cc <==
// $Id: scrollbar.cc,v 1.7 1998/09/24 13:19:48 cvs_christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "writers.hh"

void Gtk_Scrollbar::Include(File &f,const Widget &w)
{  f.include("gtk--/scrollbar.h");
}

void Gtk_Scrollbar::DeclareNeeded(File &f,const Widget &w)
{  Gtk_Adjustment::Declare(f,Widget(w,f.InstanceName(w.Name())+"_adj"));
}

void Gtk_Scrollbar::Declare(File &f,const Widget &w)
{  StandardWriter::Declare(f,w,w.Class()[3]=='H' ?"Gtk_HScrollbar":"Gtk_VScrollbar");
}

void Gtk_Scrollbar::Construct(File &f,const Widget &w,bool is_member)
{  const Widget adj(w,f.InstanceName(w.Name())+"_adj");
      
   if (is_member)
   {  Gtk_Adjustment::Construct_hv(f,adj,true,w.Class()[3]=='H' ?'h':'v');
      f << ", "
        << StandardWriter::ConstructName(f,w,is_member,"Gtk_Scrollbar")
        << "(&" << (f.InstanceName(w.Name())+"_adj") << ")";
   }
   else
   {  f << StandardWriter::ConstructName(f,w,is_member,"Gtk_Scrollbar")
        << "(0), ";
      cerr << "Gtk_Scrollbar::Construct: not member, you will run into trouble\n";
      Gtk_Adjustment::Construct_hv(f,adj,true,w.Class()[3]=='H' ?'h':'v');
   }
}

void Gtk_Scrollbar::ConstructPointer(File &f,const Widget &w)
{  Gtk_Adjustment::ConstructPointer_hv(f,Widget(w,f.InstanceName(w.Name())+"_adj"),
		w.Class()[3]=='H' ?'h':'v');
   f << ";\n\t" << f.InstanceName(w.Name()) << " = new Gtk_Scrollbar"
     << "(" << (f.InstanceName(w.Name())+"_adj") << ")";
}

void Gtk_Scrollbar::DestructPointer(File &f,const Widget &w)
{  f << "\tdelete " << f.InstanceName(w.Name()) << ";\n";
   Gtk_Adjustment::DestructPointer(f,Widget(w,f.InstanceName(w.Name())+"_adj"));
}

bool Gtk_Scrollbar::NeedConstruct(const Widget &w,bool is_member)
{  return true;
}

void Gtk_Scrollbar::Customize(File &f,const Widget &w,const string instance)
{  //Gtk_Widget::Customize(f,w,instance);
   Gtk_Entry::Customize(f,w,instance);
   string update_policy=w.getString("update_policy","GTK_UPDATE_ALWAYS");
   if (update_policy!="GTK_UPDATE_ALWAYS")
      f << instance << "set_update_policy(" << update_policy << ");\n\t";
   // find out if we must set Adjustment and do so
   // can_focus
}

==> glademm-0.2.5.tar.gz: glademm-0.2.5/src/writers/scrollbar.cc <==
// $Id: scrollbar.cc,v 1.15 1999/01/18 15:38:30 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "writers.hh"
#include "../Configuration.hh"

void Gtk_Scrollbar::Include(File &f,const Widget &w)
{  f.include("gtk--/scrollbar.h");
}

void Gtk_Scrollbar::DeclareNeeded(File &f,const Widget &w)
{  Gtk_Adjustment::Declare(f,Widget(w,f.InstanceName(w.Name())+"_adj"));
}

void Gtk_Scrollbar::Declare(File &f,const Widget &w)
{  StandardWriter::Declare(f,w,w.Class()[3]=='H' ?"Gtk_HScrollbar":"Gtk_VScrollbar");
}

void Gtk_Scrollbar::Construct(File &f,const Widget &w,bool is_member)
{  const Widget adj(w,f.InstanceName(w.Name())+"_adj");
      
   if (is_member)
   {  Gtk_Adjustment::Construct_hv(f,adj,true,w.Class()[3]=='H' ?'h':'v');
      f << ", "
        << StandardWriter::ConstructName(f,w,is_member,"Gtk_Scrollbar")
        << "("
        << (Configuration.gtkmm_version<Gtkmm_Version(0,10,0)?"&":"") 
        << (f.InstanceName(w.Name())+"_adj") << ")";
   }
   else
   {  f << StandardWriter::ConstructName(f,w,is_member,"Gtk_Scrollbar")
        << "(0), ";
      cerr << "Gtk_Scrollbar::Construct: not member, you will run into trouble\n";
      Gtk_Adjustment::Construct_hv(f,adj,true,w.Class()[3]=='H' ?'h':'v');
   }
}

void Gtk_Scrollbar::ConstructPointer(File &f,const Widget &w)
{  f << "\t" << (f.InstanceName(w.Name())+"_adj") << " = new ";
   Gtk_Adjustment::ConstructPointer_hv(f,Widget(w,f.InstanceName(w.Name())+"_adj"),
		w.Class()[3]=='H' ?'h':'v');
   f << "\t" << f.InstanceName(w.Name()) << " = new Gtk_Scrollbar"
     << "("
     << (Configuration.gtkmm_version<Gtkmm_Version(0,10,0)?"":"*") 
     << (f.InstanceName(w.Name())+"_adj") << ");\n";
}

void Gtk_Scrollbar::DestructPointer(File &f,const Widget &w)
{  f << "\tdelete " << f.InstanceName(w.Name()) << ";\n";
   Gtk_Adjustment::DestructPointer(f,Widget(w,f.InstanceName(w.Name())+"_adj"));
}

bool Gtk_Scrollbar::NeedConstruct(const Widget &w,bool is_member)
{  return true;
}

void Gtk_Scrollbar::Customize(File &f,const Widget &w,const string instance)
{  //Gtk_Widget::Customize(f,w,instance);
   Gtk_Range::Customize(f,w,instance);
   string update_policy=w.getString("update_policy","GTK_UPDATE_ALWAYS");
   if (update_policy!="GTK_UPDATE_ALWAYS")
      f << instance << "set_update_policy(" << update_policy << ");\n\t";
   // find out if we must set Adjustment and do so
   // can_focus
}
